@@ -1,8 +1,9 @@
 # flake8: noqa
 
-from tune_notebook.vis import (
+from tune_notebook.monitors import (
     NotebookSimpleChart,
     NotebookSimpleHist,
     NotebookSimpleRungs,
     NotebookSimpleTimeSeries,
+    PrintBest,
 )
